@@ -13,9 +13,11 @@ def exit_handler(export_path: Optional[Path]):
     if export_path:
         if console.record:
             console.save_html(export_path)
+            console.print(f"The command output has been saved to {export_path}")
         else:
             console.print(
-                f"Cannot save HTML {export_path} bacause the command session has been recorded",
+                f"Will not save HTML {export_path} because the command did not yield "
+                f"any results or session has not been recorded.",
                 style="warning",
             )
 
