@@ -19,45 +19,61 @@ from threedi_cmd_statistics.validators.models import OptionsValidator
 from threedi_cmd_statistics.models import SessionsOptions, UsageOptions
 
 
-def html_callback(html_export_path: str):
+def html_callback(html_export_path: Path):
     atexit.register(exit_handler, export_path=html_export_path)
+    return html_export_path
 
 
-HtmlExportPath = typer.Option(
+HtmlExportPathOption = typer.Option(
     None,
     exists=False,
     dir_okay=True,
     writable=True,
     resolve_path=True,
-    help="Export results to a html file.",
+    help="Export the command output to a html file.",
     callback=html_callback
 )
 
 
+VerboseOption: bool = typer.Option(
+    False,
+    help="In case of command failures this will give you more detailed information, "
+         "like the underlying tracebacks"
+)
+
+
 def stats_callback(
     ctx: typer.Context,
     endpoint: EndpointChoices = typer.Option(
         EndpointChoices.production, case_sensitive=False
     ),
     month: MonthsChoices = typer.Option(
-        None, help="month of the current year"
+        None,
+        help="Numerical month representation, e.g. 1 for January, 2 for February,..."
+             "If used without the --year option the current year will used automatically"
     ),
-    year: str = typer.Option(None, help="sessions throughout the whole year"),
+    year: str = typer.Option(
+        None,
+        help="Limit the results to a specific year. This option is mutually exclusive with "
+             "the --date option."),
     date: Optional[List[datetime]] = typer.Option(
         None,
-        help="sessions since the given date. "
+        help="Statistics since the given date. "
              "Use a second date option to select a custom period of time. ",
     ),
-    user_filter: str = typer.Option(None, help="filter by user name"),
-    organisation_filter: str = typer.Option(
-        None, help="filter by organisation uuid"
+    user_filter: str = typer.Option(
+        None,
+        help="Filter by user name, e.g <user>.<name>"
     ),
-    html_export_path: Path = HtmlExportPath,
-    verbose: bool = typer.Option(
-        False,
-        help="Show tracebacks and such",
+    organisation_filter: Optional[List[str]] = typer.Option(
+        None, help="Filter by organisation uuid, e.g. <78f5a464c35044c19bc7d4b42d7f43dc> "
+                   "You can supply multiple organisations by specifying this option multiple times. "
+                   "Use 'all' to automatically get results for all active organisations"
     ),
+    html_export_path: Path = HtmlExportPathOption,
+    verbose: bool = VerboseOption,
 ):
+    """default: 3Di statistics since the beginning of the 3Di era"""
     options_validator = OptionsValidator(
         month, year, date, user_filter, organisation_filter
     )
@@ -80,5 +96,3 @@ def stats_callback(
         return
     ctx.obj = options
     ctx.call_on_close(Settings.save_settings)
-
-
