@@ -2,7 +2,9 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional, List
 from enum import Enum
+
 from threedi_cmd_statistics.validators.dates import validate_dates, validate_year
+from threedi_cmd_statistics.validators.strings import validate_organisations
 from threedi_cmd_statistics.validators import ValidationError
 
 
@@ -12,7 +14,7 @@ class OptionsValidator:
     year: Optional[str]
     dates: Optional[List[datetime]]
     user_filter: Optional[str]
-    organisation_filter: Optional[str]
+    organisation_filter: Optional[List[str]]
 
     def validate(self) -> None:
         """
@@ -25,3 +27,6 @@ class OptionsValidator:
 
         if self.dates:
             validate_dates(self.dates)
+
+        if self.organisation_filter:
+            validate_organisations(self.organisation_filter)
